@@ -71,7 +71,7 @@ fn update_member_deps(dir: &Path, version: &Version) -> HashMap<String, HashSet<
                         if let Some(Some(_)) = dep.get("path").map(|dep| dep.as_str()) {
                             // this is a local dependency, so we will need to update the version
                             dep.insert("version", toml_edit::value(version.to_string()));
-                            local_deps.insert(name.to_string());
+                            local_deps.insert(name.trim().into());
                         }
                     }
                 }
@@ -83,7 +83,7 @@ fn update_member_deps(dir: &Path, version: &Version) -> HashMap<String, HashSet<
         file.write_all(member_toml.to_string().as_bytes()).unwrap();
 
 
-        graph.insert(member.to_string(), local_deps);
+        graph.insert(member.trim().into(), local_deps);
     }
 
     // now we have a graph of dependencies, we can figure out which
